@@ -2,6 +2,8 @@
 #
 # SPDX-License-Identifier: GPL-3.0-only
 
+from typing import List
+
 from .about import About
 from .accounts import Accounts
 from .instances import Instances
@@ -9,4 +11,4 @@ from .news import News
 from .settings import Settings
 from .update import Update
 
-__all__ = ["About", "Accounts", "Instances", "News", "Settings", "Update"]
+__all__: List[str] = ["About", "Accounts", "Instances", "News", "Settings", "Update"]
