@@ -7,6 +7,7 @@ import tkinter
 from customtkinter import CTkFrame, CTkLabel
 
 from .__about__ import __version__
+from .components.heading import Heading
 
 
 class About(CTkFrame):
@@ -15,15 +16,8 @@ class About(CTkFrame):
 
         self.grid_columnconfigure(0, weight=1)
 
-        self.title_frame = CTkFrame(master=self, fg_color="gray38")
-        self.title_frame.grid(row=0, column=0, pady=20, padx=20, sticky="nswe")
-
-        self.app_name = CTkLabel(
-            master=self.title_frame,
-            text_font=("Roboto Medium", 30),
-            text="Ice Launcher",
-        )
-        self.app_name.grid(row=0, column=0, pady=20, padx=20, sticky="nswe")
+        heading = Heading(master=self, text="Ice Launcher")
+        heading.grid(row=0, column=0, pady=20, padx=20, sticky="nwe")
 
         self.info_frame = CTkFrame(master=self)
         self.info_frame.grid(row=1, column=0, pady=20, padx=20, sticky="nswe")
