@@ -10,6 +10,7 @@ from tkinter import ttk
 from customtkinter import CTkButton, CTkFrame, CTkLabel
 from minecraft_launcher_lib import microsoft_account as msa
 
+from .components.heading import Heading
 from .components.scrollable_frame import ScrollableFrame
 from .lib import accounts
 
@@ -57,20 +58,12 @@ class Accounts(CTkFrame):
 
         self.doc = accounts.read_document()
 
-        self.title_frame = CTkFrame(master=self, fg_color="gray38")
-        self.title_frame.grid(row=0, column=0, pady=20, padx=20, sticky="nswe")
-
-        self.view_name = CTkLabel(
-            master=self.title_frame,
-            text_font=("Roboto Medium", 30),
-            text="Accounts",
-        )
-        self.view_name.grid(row=0, column=0, pady=20, padx=20, sticky="nswe")
+        heading = Heading(self, "Accounts")
+        heading.grid(row=0, column=0, pady=20, padx=20, sticky="nwe")
 
         self.accounts_list = ScrollableFrame(master=self)
         self.accounts_list.grid(row=1, column=0, pady=20, padx=20, sticky="nswe")
         self.grid_rowconfigure(1, weight=1)
-        self.accounts_list.content.grid_columnconfigure(0, weight=1)
 
         self.update_accounts_list()
 
@@ -97,17 +90,26 @@ class Accounts(CTkFrame):
             account.destroy()
 
         for index, account in enumerate(self.doc["accounts"]):
-            label = CTkLabel(master=self.accounts_list.content, text=account["name"])
+            label = CTkLabel(
+                master=self.accounts_list.content, text=account["name"], anchor="w"
+            )
             label.grid(row=index * 2, column=0, pady=10, padx=0, sticky="nw")
             delete_button = CTkButton(
                 master=self.accounts_list.content,
                 text="Delete",
                 command=lambda index=index: self.delete_account(index),
             )
-            delete_button.grid(row=index * 2, column=1, pady=10, padx=10, sticky="e")
+            delete_button.grid(
+                row=index * 2, column=1, pady=10, padx=(0, 10), sticky="e"
+            )
             separator = ttk.Separator(self.accounts_list.content, orient="horizontal")
             separator.grid(
-                row=index * 2 + 1, column=0, columnspan=2, pady=0, padx=10, sticky="ew"
+                row=index * 2 + 1,
+                column=0,
+                columnspan=2,
+                pady=0,
+                padx=(0, 10),
+                sticky="ew",
             )
 
         add_account_button = CTkButton(
@@ -116,5 +118,5 @@ class Accounts(CTkFrame):
             command=self.add_account,
         )
         add_account_button.grid(
-            row=len(self.doc["accounts"]) * 2, column=0, pady=20, padx=20, sticky="nw"
+            row=len(self.doc["accounts"]) * 2, column=0, pady=20, padx=0, sticky="nw"
         )
